@@ -6,54 +6,52 @@ Designed by Marcell Ban aka BxNxM
 """
 from time import localtime
 from re import match
-from uos import listdir, remove, stat, mkdir, getcwd
+from uos import remove, mkdir
+from Files import OSPath, path_join, ilist_fs, is_dir
 
 #############################################
 #        LOGGING WITH DATA ROTATION         #
 #############################################
-LOG_FOLDER = None
 
 def _init_logger():
     """ Init /logs folder """
-    global LOG_FOLDER
-    if LOG_FOLDER is None:
-        LOG_FOLDER = f"{getcwd()}logs"
-        do_create = True
+    if not is_dir(OSPath.LOGS):
         try:
-            if stat(LOG_FOLDER)[0] & 0x4000:
-                # Dir exists - skip create
-                do_create = False
-        except:
-            pass
-        if do_create:
-            try:
-                mkdir(LOG_FOLDER)
-                syslog(f"[BOOT] log dir {LOG_FOLDER} init")
-            except Exception as e:
-                LOG_FOLDER = getcwd()
-                syslog(f"[BOOT] log dir {LOG_FOLDER} fallback: {e}")
-    return LOG_FOLDER
+            mkdir(OSPath.LOGS)
+            syslog(f"[BOOT] log dir {OSPath.LOGS} init")
+        except Exception as e:
+            OSPath.LOGS = OSPath.ROOT
+            syslog(f"[BOOT] log dir {OSPath.LOGS} fallback: {e}")
+    return OSPath.LOGS
 
 
-def logger(data, f_name, limit):
+def _dir_select(f_name:str) -> str:
     """
-    Create generic logger function
-    - implements log line rotation
-    - automatic time stump
-    :param data: input string data to log
+    Select log dir based on file extension
+    :param f_name: filename with extension to detect target dir
+    """
+    if f_name.endswith(".log"):
+        return OSPath.LOGS
+    return OSPath.DATA
+
+
+def logger(data, f_name:str, limit:int):
+    """
+    Generic logger function with line rotation and time
+    :param data: data to log
     :param f_name: file name to use
     :param limit: line limit for log rotation
     return write verdict - true / false
     INFO: hardcoded max data number = 30
     """
     def _logger(f_mode='r+'):
-        nonlocal data, f_name, limit
+        nonlocal data, f_path, limit
         limit = min(limit, 30)  # Hardcoded max data line = 30
         # [1] GET TIME STUMP
         ts_buff = [str(k) for k in localtime()]
         ts = ".".join(ts_buff[0:3]) + "-" + ":".join(ts_buff[3:6])
         # [2] OPEN FILE - WRITE DATA WITH TS
-        with open(f_name, f_mode) as f:
+        with open(f_path, f_mode) as f:
             _data = f"{ts} {data}\n"
             # read file lines and filter by time stump chunks (hack for replace truncate)
             lines = [_l for _l in f.readlines() if '-' in _l and '.' in _l]
@@ -67,7 +65,7 @@ def logger(data, f_name, limit):
             # write file
             f.write(''.join(lines))
 
-    f_name = f"{LOG_FOLDER}/{f_name}"
+    f_path = path_join(_dir_select(f_name), f_name)
     # Run logger
     try:
         # There is file - append 'r+'
@@ -81,17 +79,17 @@ def logger(data, f_name, limit):
     return True
 
 
-def log_get(f_name, msgobj=None):
+def log_get(f_name:str, msgobj=None):
     """
-    Get and stream (ver osocket/stdout) .log file's content and count "critical" errors
-    - critical error tag in log line: [ERR]
+    Generic file getter for .log files
+    - log content critical [ERR] counter
     """
-    f_name = f"{LOG_FOLDER}/{f_name}"
+    f_path = path_join(_dir_select(f_name), f_name)
     err_cnt = 0
     try:
         if msgobj is not None:
-            msgobj(f_name)
-        with open(f_name, 'r') as f:
+            msgobj(f_path)
+        with open(f_path, 'r') as f:
             eline = f.readline().strip()
             while eline:
                 # GET error from log line (tag: [ERR])
@@ -106,10 +104,16 @@ def log_get(f_name, msgobj=None):
 
 
 def syslog(data=None, msgobj=None):
+    """
+    System log setter/getter
+    :param data: None - read logs, str - write logs
+    :param msgobj: function to stream .log files
+    """
     if data is None:
-        err_cnt = sum([log_get(f, msgobj) for f in listdir(LOG_FOLDER) if f.endswith(".sys.log")])
+        # READ LOGS
+        err_cnt = sum([log_get(f, msgobj) for f in ilist_fs(OSPath.LOGS, type_filter='f') if f.endswith(".sys.log")])
         return err_cnt
-
+    # WRITE LOGS - [target].sys.log automatic log level detection
     _match = match(r"^\[([^\[\]]+)\]", data)
     log_lvl = _match.group(1).lower() if _match else 'user'
     f_name = f"{log_lvl}.sys.log" if log_lvl in ("err", "warn", "boot") else 'user.sys.log'
@@ -117,9 +121,13 @@ def syslog(data=None, msgobj=None):
 
 
 def log_clean(msgobj=None):
-    to_del = [file for file in listdir(LOG_FOLDER) if file.endswith('.log')]
+    """
+    Clean logs folder
+    """
+    logs_dir = OSPath.LOGS
+    to_del = [file for file in ilist_fs(logs_dir, type_filter='f') if file.endswith('.log')]
     for _del in to_del:
-        _del = f"{LOG_FOLDER}/{_del}"
+        _del = path_join(logs_dir, _del)
         if msgobj is not None:
             msgobj(f" Delete: {_del}")
         remove(_del)
