@@ -12,9 +12,9 @@ Designed by Marcell Ban aka BxNxM
 #                           IMPORTS                             #
 #################################################################
 from sys import modules
-from uos import listdir
 from machine import reset as hard_reset, soft_reset
 from Config import cfgget, cfgput
+from Files import ilist_fs
 from Tasks import lm_exec
 from Debug import errlog_add
 
@@ -25,7 +25,7 @@ from Debug import errlog_add
 
 class Shell:
     __slots__ = ['__devfid', '__auth_mode', '__hwuid', '__auth_ok', '__conf_mode']
-    MICROS_VERSION = '2.10.2-0'
+    MICROS_VERSION = '2.11.0-0'
 
     def __init__(self):
         """
@@ -106,7 +106,8 @@ class Shell:
             # No msg to work with
             return True
         msg_list = msg.strip().split()
-        local_cmd = not msg_list[-1].startswith(">>")   # intercon request check for shell commands
+        # INTERCON embedding: conf mode and remote call request check
+        is_local_cmd = self.__conf_mode or not msg_list[-1].startswith(">>")
 
         ##########################################
         #   [1] Handle built-in shell commands   #
@@ -114,7 +115,7 @@ class Shell:
         ##########################################
 
         # Hello message
-        if local_cmd and msg_list[0] == 'hello':
+        if is_local_cmd and msg_list[0] == 'hello':
             # For low level device identification - hello msg
             await self.a_send(f"hello:{self.__devfid}:{self.__hwuid}")
             return True
@@ -127,62 +128,65 @@ class Shell:
             return True
 
         # Version handling
-        if local_cmd and msg_list[0] == 'version':
+        if is_local_cmd and msg_list[0] == 'version':
             # For micrOS system version info
             await self.a_send(str(Shell.MICROS_VERSION))
             return True
 
         # Reboot micropython VM
-        if local_cmd and msg_list[0] == 'reboot':
+        if is_local_cmd and msg_list[0] == 'reboot':
             hard = False
             if len(msg_list) >= 2 and "-h" in msg_list[1]:
                 # reboot / reboot -h
                 hard = True
             await self.reboot(hard)
 
-        if local_cmd and msg_list[0].startswith('webrepl'):
+        if is_local_cmd and msg_list[0].startswith('webrepl'):
             if len(msg_list) == 2 and '-u' in msg_list[1]:
                 await Shell.webrepl(msg_obj=self.a_send, update=True)
             return await Shell.webrepl(msg_obj=self.a_send)
 
         # CONFIGURE MODE STATE: ACCESS FOR NODE_CONFIG.JSON
-        if local_cmd and msg_list[0].startswith('conf'):
+        if is_local_cmd and msg_list[0].startswith('conf'):
             self.__conf_mode = True
             return True
-        if local_cmd and msg_list[0].startswith('noconf'):
+        if is_local_cmd and msg_list[0].startswith('noconf'):
             self.__conf_mode = False
             return True
 
         # HELP MSG
-        if local_cmd and msg_list[0] == "help":
-            await self.a_send("[MICROS]     - built-in shell commands")
+        if is_local_cmd and msg_list[0] == "help":
+            await self.a_send("[MICROS]")
             await self.a_send("   hello     - hello msg - for device identification")
             await self.a_send("   modules   - show active Load Modules")
             await self.a_send("   version   - returns micrOS version")
-            await self.a_send("   exit      - exit from shell socket prompt")
+            await self.a_send("   exit      - exit shell session")
             await self.a_send("   reboot    - system soft reboot (vm), hard reboot (hw): reboot -h")
             await self.a_send("   webrepl   - start webrepl, for file transfers use with --update")
-            await self.a_send("[CONF] Configure mode - built-in shell commands")
+            await self.a_send("[CONF] Configuration mode")
             await self.a_send("  conf       - Enter conf mode")
-            await self.a_send("    dump       - Dump all data")
+            await self.a_send("    dump       - Dump all data, filter: dump <str>")
             await self.a_send("    key        - Get value")
             await self.a_send("    key value  - Set value")
             await self.a_send("  noconf     - Exit conf mode")
-            await self.a_send("[TASK] postfix: ...&x - one-time, ...&&x - periodic, x: wait ms [x min: 20ms]")
-            await self.a_send("  task list         - list tasks by <tag>s")
+            await self.a_send("[TASK] Task operations")
+            await self.a_send("  task list         - list tasks by tags")
             await self.a_send("  task kill <tag>   - stop task")
             await self.a_send("  task show <tag>   - show task output")
-            await self.a_send("[EXEC] Command mode (LMs):")
-            await self.a_send("  >>node01.local    - INTERCON postfix, execute command on remote device")
-            await self.a_send("  >json             - JSON postfix, request json formatted output")
-            await self.a_send("  help lm           - list ALL LoadModules")
+            await self.a_send("[EXEC] Command mode, syntax(...): <module> <function> <params> <postfix>")
+            await self.a_send("  Postfix hints:")
+            await self.a_send("    ... &<x>            - start one-shot task")
+            await self.a_send("    ... &&<x>           - start periodic task, where <x>: delay ms [x min: 20ms]")
+            await self.a_send("    ... >>hostname      - remote command execution (intercon)")
+            await self.a_send("    ... >json           - request json formatted output")
+            await self.a_send("  help lm           - list ALL available LoadModules")
             if "lm" in str(msg_list):
                 return await Shell._show_lm_funcs(msg_obj=self.a_send)
             return await Shell._show_lm_funcs(msg_obj=self.a_send, active_only=True)
 
         # [2] EXECUTE:
         # @1 Configure mode
-        if local_cmd and self.__conf_mode and len(msg_list) > 0:
+        if is_local_cmd and self.__conf_mode and len(msg_list) > 0:
             # Lock thread under config handling is threads available
             return await Shell._configure(self.a_send, msg_list)
         # @2 Command mode
@@ -252,13 +256,13 @@ class Shell:
         Dump LM modules with functions - in case of [py] files
         Dump LM module with help function call - in case of [mpy] files
         """
-        async def _help(mod):
-            for lm_path in (i for i in mod if i.startswith('LM_') and (i.endswith('py'))):
+        async def _help(mods):
+            for lm_path in mods:
                 lm_name = lm_path.replace('LM_', '').split('.')[0]
                 try:
-                    await msg_obj(f"   {lm_name}")
+                    await msg_obj(f"  {lm_name}")
                     if lm_path.endswith('.mpy'):
-                        await msg_obj(f"   {' ' * len(lm_path.replace('LM_', '').split('.')[0])}help")
+                        await msg_obj(f"  {' ' * len(lm_path.replace('LM_', '').split('.')[0])}help")
                         continue
                     with open(lm_path, 'r') as f:
                         line = "micrOSisTheBest"
@@ -266,19 +270,20 @@ class Shell:
                             line = f.readline()
                             ldata = line.strip()
                             if ldata.startswith('def ') and not ldata.split()[1].startswith("_") and 'self' not in ldata:
-                                await msg_obj(f"   {' ' * len(lm_name)}{ldata.replace('def ', '').split('(')[0]}")
+                                await msg_obj(f"  {' ' * len(lm_name)}{ldata.replace('def ', '').split('(')[0]}")
                 except Exception as e:
                     await msg_obj(f"[{lm_path}] SHOW LM PARSER WARNING: {e}")
                     return False
             return True
 
+        await msg_obj("")
         # [1] list active modules (default in shell)
         if active_only:
             mod_keys = modules.keys()
-            active_modules = (dir_mod for dir_mod in listdir() if dir_mod.split('.')[0] in mod_keys)
+            active_modules = (dir_mod for dir_mod in ilist_fs(type_filter='f', select="LM") if dir_mod.split('.')[0] in mod_keys)
             return await _help(active_modules)
         # [2] list all LMs on file system (ALL - help lm) - manual
-        return await _help(listdir())
+        return await _help(ilist_fs(type_filter='f', select="LM"))
 
     @staticmethod
     async def webrepl(msg_obj, update=False):
