@@ -44,7 +44,7 @@ class TaskBase:
         self.out = ""                # Store task output
 
     @staticmethod
-    def is_busy(tag) -> bool:
+    def is_busy(tag:str) -> bool:
         """
         Check task is busy by tag
         :param tag: for task selection
@@ -98,9 +98,11 @@ class TaskBase:
     async def feed(sleep_ms=1):
         """
         Feed event loop
-        :param sleep_ms: in millisecond (min: 1)
+        :param sleep_ms: in millisecond
         """
         # TODO: feed WDT - preemptive cooperative multitasking aka reboot if no feed until X time period
+        if sleep_ms <= 0:
+            return await asyncio.sleep(0.000_000_1)     # 0 means: 100ns (Absolute minimum)
         return await asyncio.sleep_ms(sleep_ms)
 
     def __del__(self):
@@ -116,7 +118,7 @@ class NativeTask(TaskBase):
     - could be built in function or custom code from load modules
     """
 
-    def create(self, callback=None, tag=None):
+    def create(self, callback:callable=None, tag:str=None) -> bool:
         """
         Create async task with coroutine callback (no queue limit check!)
         + async socket server task
@@ -166,7 +168,7 @@ class MagicTask(TaskBase):
         self.__inloop = False        # [LM] Task while loop for LM callback
         self.__sleep = 20            # [LM] Task while loop - async wait (proc feed) [ms]
 
-    def create(self, callback=None, loop=None, sleep=None):
+    def create(self, callback:list=None, loop:bool=None, sleep:int=None) -> bool:
         """
         Create async task with function callback (with queue limit check)
         - wrap (sync) function into async task (task_wrapper)
@@ -295,11 +297,12 @@ class Manager:
         my_task.done.set()
 
     @staticmethod
-    def create_task(callback, tag=None, loop=False, delay=None):
+    def create_task(callback, tag:str=None, loop:bool=False, delay:int=None):
         """
         Primary interface
         Generic task creator method
             Create async Task with coroutine/list(lm call) callback
+        :param callback: list|callable
         """
         if isinstance(callback, list):
             # Check queue if task is Load Module
@@ -335,7 +338,7 @@ class Manager:
             _tasks = []
             tag_parts = tag.split('.')
             for t in TaskBase.TASKS:
-                if t.startswith(tag_parts[0]) and len(tag_parts) > 1 and tag_parts[1] == '*':
+                if len(tag_parts) > 1 and t.startswith('.'.join(tag_parts[0:-1])) and tag_parts[-1] == '*':
                     _tasks.append(t)
             if len(_tasks) == 0:
                 return []
