@@ -10,7 +10,8 @@ Designed by Marcell Ban aka BxNxM
 #                           IMPORTS                             #
 #################################################################
 from sys import platform
-from uos import listdir, uname
+from uos import uname
+from Files import ilist_fs
 from Logger import syslog
 
 #################################################################
@@ -29,17 +30,19 @@ def detect_platform():
     """
     Unified platform detection for micrOS
     """
-    if 'esp32' in platform:
+    if 'esp32' in platform:     # esp32 family
         board = str(uname()[-1]).lower()
         if 'tinypico' in board:
-            return 'tinypico'    # esp32 family - tinypico
+            return 'tinypico'
         if 'esp32s2' in board:
-            return 'esp32s2'     # esp32 family - esp32S2
+            return 'esp32s2'
         if 'esp32s3' in board:
-            return 'esp32s3'     # esp32 family - esp32s3
+            return 'esp32s3'
         if 'esp32c3' in board:
-            return 'esp32c3'     # esp32 family - esp32c3
-        return 'esp32'           # esp32 family - general
+            return 'esp32c3'
+        if 'esp32c6' in board:
+            return 'esp32c6'
+        return 'esp32'           # esp32 family: general
     return platform              # esp8266 or something else
 
 
@@ -65,7 +68,7 @@ def set_pinmap(map_data=None):
 
     # SELECT LOOKUP TABLE BASED ON PLATFORM / User input
     if isinstance(io_file, str) and io_file != 'n/a':
-        if f"IO_{io_file}" in [io.split('.')[0] for io in listdir() if io.startswith('IO_')]:
+        if f"IO_{io_file}" in [io.split('.')[0] for io in ilist_fs(type_filter='f', select="IO")]:
             PinMap.MAPPING_LUT = io_file
             return PinMap.MAPPING_LUT
     PinMap.MAPPING_LUT = detect_platform()
