@@ -1,5 +1,9 @@
-from os import listdir
+"""
+Easy reset for webrepl terminal
+"""
+
 from time import sleep
+from uos import listdir
 from machine import soft_reset, reset
 
 print('Device reboot now, boot micrOSloader...')
